==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkImageThreshold.java <==
// java wrapper for vtkImageThreshold object
//

package vtk;
import vtk.*;

public class vtkImageThreshold extends vtkThreadedImageAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void ThresholdByUpper_2(double id0);
  public void ThresholdByUpper(double id0)
    { ThresholdByUpper_2(id0); }

  private native void ThresholdByLower_3(double id0);
  public void ThresholdByLower(double id0)
    { ThresholdByLower_3(id0); }

  private native void ThresholdBetween_4(double id0,double id1);
  public void ThresholdBetween(double id0,double id1)
    { ThresholdBetween_4(id0,id1); }

  private native void SetReplaceIn_5(int id0);
  public void SetReplaceIn(int id0)
    { SetReplaceIn_5(id0); }

  private native int GetReplaceIn_6();
  public int GetReplaceIn()
    { return GetReplaceIn_6(); }

  private native void ReplaceInOn_7();
  public void ReplaceInOn()
    { ReplaceInOn_7(); }

  private native void ReplaceInOff_8();
  public void ReplaceInOff()
    { ReplaceInOff_8(); }

  private native void SetInValue_9(double id0);
  public void SetInValue(double id0)
    { SetInValue_9(id0); }

  private native double GetInValue_10();
  public double GetInValue()
    { return GetInValue_10(); }

  private native void SetReplaceOut_11(int id0);
  public void SetReplaceOut(int id0)
    { SetReplaceOut_11(id0); }

  private native int GetReplaceOut_12();
  public int GetReplaceOut()
    { return GetReplaceOut_12(); }

  private native void ReplaceOutOn_13();
  public void ReplaceOutOn()
    { ReplaceOutOn_13(); }

  private native void ReplaceOutOff_14();
  public void ReplaceOutOff()
    { ReplaceOutOff_14(); }

  private native void SetOutValue_15(double id0);
  public void SetOutValue(double id0)
    { SetOutValue_15(id0); }

  private native double GetOutValue_16();
  public double GetOutValue()
    { return GetOutValue_16(); }

  private native double GetUpperThreshold_17();
  public double GetUpperThreshold()
    { return GetUpperThreshold_17(); }

  private native double GetLowerThreshold_18();
  public double GetLowerThreshold()
    { return GetLowerThreshold_18(); }

  private native void SetOutputScalarType_19(int id0);
  public void SetOutputScalarType(int id0)
    { SetOutputScalarType_19(id0); }

  private native int GetOutputScalarType_20();
  public int GetOutputScalarType()
    { return GetOutputScalarType_20(); }

  private native void SetOutputScalarTypeToDouble_21();
  public void SetOutputScalarTypeToDouble()
    { SetOutputScalarTypeToDouble_21(); }

  private native void SetOutputScalarTypeToFloat_22();
  public void SetOutputScalarTypeToFloat()
    { SetOutputScalarTypeToFloat_22(); }

  private native void SetOutputScalarTypeToLong_23();
  public void SetOutputScalarTypeToLong()
    { SetOutputScalarTypeToLong_23(); }

  private native void SetOutputScalarTypeToUnsignedLong_24();
  public void SetOutputScalarTypeToUnsignedLong()
    { SetOutputScalarTypeToUnsignedLong_24(); }

  private native void SetOutputScalarTypeToInt_25();
  public void SetOutputScalarTypeToInt()
    { SetOutputScalarTypeToInt_25(); }

  private native void SetOutputScalarTypeToUnsignedInt_26();
  public void SetOutputScalarTypeToUnsignedInt()
    { SetOutputScalarTypeToUnsignedInt_26(); }

  private native void SetOutputScalarTypeToShort_27();
  public void SetOutputScalarTypeToShort()
    { SetOutputScalarTypeToShort_27(); }

  private native void SetOutputScalarTypeToUnsignedShort_28();
  public void SetOutputScalarTypeToUnsignedShort()
    { SetOutputScalarTypeToUnsignedShort_28(); }

  private native void SetOutputScalarTypeToChar_29();
  public void SetOutputScalarTypeToChar()
    { SetOutputScalarTypeToChar_29(); }

  private native void SetOutputScalarTypeToSignedChar_30();
  public void SetOutputScalarTypeToSignedChar()
    { SetOutputScalarTypeToSignedChar_30(); }

  private native void SetOutputScalarTypeToUnsignedChar_31();
  public void SetOutputScalarTypeToUnsignedChar()
    { SetOutputScalarTypeToUnsignedChar_31(); }

  public vtkImageThreshold() { super(); }

  public vtkImageThreshold(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-1-armv6h.pkg.tar.xz: vtk/vtkImageThreshold.java <==
// java wrapper for vtkImageThreshold object
//

package vtk;
import vtk.*;

public class vtkImageThreshold extends vtkThreadedImageAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void ThresholdByUpper_2(double id0);
  public void ThresholdByUpper(double id0)
    { ThresholdByUpper_2(id0); }

  private native void ThresholdByLower_3(double id0);
  public void ThresholdByLower(double id0)
    { ThresholdByLower_3(id0); }

  private native void ThresholdBetween_4(double id0,double id1);
  public void ThresholdBetween(double id0,double id1)
    { ThresholdBetween_4(id0,id1); }

  private native void SetReplaceIn_5(int id0);
  public void SetReplaceIn(int id0)
    { SetReplaceIn_5(id0); }

  private native int GetReplaceIn_6();
  public int GetReplaceIn()
    { return GetReplaceIn_6(); }

  private native void ReplaceInOn_7();
  public void ReplaceInOn()
    { ReplaceInOn_7(); }

  private native void ReplaceInOff_8();
  public void ReplaceInOff()
    { ReplaceInOff_8(); }

  private native void SetInValue_9(double id0);
  public void SetInValue(double id0)
    { SetInValue_9(id0); }

  private native double GetInValue_10();
  public double GetInValue()
    { return GetInValue_10(); }

  private native void SetReplaceOut_11(int id0);
  public void SetReplaceOut(int id0)
    { SetReplaceOut_11(id0); }

  private native int GetReplaceOut_12();
  public int GetReplaceOut()
    { return GetReplaceOut_12(); }

  private native void ReplaceOutOn_13();
  public void ReplaceOutOn()
    { ReplaceOutOn_13(); }

  private native void ReplaceOutOff_14();
  public void ReplaceOutOff()
    { ReplaceOutOff_14(); }

  private native void SetOutValue_15(double id0);
  public void SetOutValue(double id0)
    { SetOutValue_15(id0); }

  private native double GetOutValue_16();
  public double GetOutValue()
    { return GetOutValue_16(); }

  private native double GetUpperThreshold_17();
  public double GetUpperThreshold()
    { return GetUpperThreshold_17(); }

  private native double GetLowerThreshold_18();
  public double GetLowerThreshold()
    { return GetLowerThreshold_18(); }

  private native void SetOutputScalarType_19(int id0);
  public void SetOutputScalarType(int id0)
    { SetOutputScalarType_19(id0); }

  private native int GetOutputScalarType_20();
  public int GetOutputScalarType()
    { return GetOutputScalarType_20(); }

  private native void SetOutputScalarTypeToDouble_21();
  public void SetOutputScalarTypeToDouble()
    { SetOutputScalarTypeToDouble_21(); }

  private native void SetOutputScalarTypeToFloat_22();
  public void SetOutputScalarTypeToFloat()
    { SetOutputScalarTypeToFloat_22(); }

  private native void SetOutputScalarTypeToLong_23();
  public void SetOutputScalarTypeToLong()
    { SetOutputScalarTypeToLong_23(); }

  private native void SetOutputScalarTypeToUnsignedLong_24();
  public void SetOutputScalarTypeToUnsignedLong()
    { SetOutputScalarTypeToUnsignedLong_24(); }

  private native void SetOutputScalarTypeToInt_25();
  public void SetOutputScalarTypeToInt()
    { SetOutputScalarTypeToInt_25(); }

  private native void SetOutputScalarTypeToUnsignedInt_26();
  public void SetOutputScalarTypeToUnsignedInt()
    { SetOutputScalarTypeToUnsignedInt_26(); }

  private native void SetOutputScalarTypeToShort_27();
  public void SetOutputScalarTypeToShort()
    { SetOutputScalarTypeToShort_27(); }

  private native void SetOutputScalarTypeToUnsignedShort_28();
  public void SetOutputScalarTypeToUnsignedShort()
    { SetOutputScalarTypeToUnsignedShort_28(); }

  private native void SetOutputScalarTypeToChar_29();
  public void SetOutputScalarTypeToChar()
    { SetOutputScalarTypeToChar_29(); }

  private native void SetOutputScalarTypeToSignedChar_30();
  public void SetOutputScalarTypeToSignedChar()
    { SetOutputScalarTypeToSignedChar_30(); }

  private native void SetOutputScalarTypeToUnsignedChar_31();
  public void SetOutputScalarTypeToUnsignedChar()
    { SetOutputScalarTypeToUnsignedChar_31(); }

  public vtkImageThreshold() { super(); }

  public vtkImageThreshold(long id) { super(id); }
  public native long   VTKInit();

}
